pub struct AlertMatchType(/* private fields */);Expand description
How a condition must be met over the evaluation window.
Implementations
Sourceimpl AlertMatchType
impl AlertMatchType
Sourcepub const AT_LEAST_ONCE: Self
pub const AT_LEAST_ONCE: Self
Fire if the threshold is crossed at least once. The default.
Sourcepub const ALL_THE_TIME: Self
pub const ALL_THE_TIME: Self
Fire only if crossed for the whole window.
Sourcepub const ON_AVERAGE: Self
pub const ON_AVERAGE: Self
Fire on the window average.