pub struct BatchCall {Show 23 fields
pub batch_id: String,
pub batch_name: Option<String>,
pub description: Option<String>,
pub phone_number_id: Option<String>,
pub phone_number: Option<String>,
pub routing_rule_id: Option<String>,
pub timing: Option<BatchCallTiming>,
pub timezone: Option<String>,
pub scheduled_time: Option<String>,
pub scheduled_date: Option<String>,
pub allowed_from: Option<String>,
pub allowed_until: Option<String>,
pub days_of_week: Vec<u32>,
pub retry: Option<BatchCallRetryConfig>,
pub status: Option<BatchCallStatus>,
pub cdn_url: Option<String>,
pub records_uploaded: Option<u32>,
pub parse_error: Option<String>,
pub timestamp: Option<i64>,
pub progress: Option<f64>,
pub created_at: Option<String>,
pub updated_at: Option<String>,
pub extra: Map<String, Value>,
}Expand description
A bulk outbound phone campaign.
Fields
batch_id: StringThe batch id.
batch_name: Option<String>The batch’s display name.
description: Option<String>The batch’s description.
phone_number_id: Option<String>The outbound phone number id.
phone_number: Option<String>The outbound phone number.
routing_rule_id: Option<String>The outbound routing rule id.
timing: Option<BatchCallTiming>When the batch runs.
timezone: Option<String>The IANA timezone the schedule is interpreted in.
scheduled_time: Option<String>The scheduled time, as HH:MM.
scheduled_date: Option<String>The scheduled date, as YYYY-MM-DD.
allowed_from: Option<String>The start of the allowed calling window, as HH:MM.
allowed_until: Option<String>The end of the allowed calling window, as HH:MM.
days_of_week: Vec<u32>The days the batch may call: 0 is Sunday through 6, Saturday.
retry: Option<BatchCallRetryConfig>The batch’s retry configuration.
status: Option<BatchCallStatus>The batch’s status.
cdn_url: Option<String>Where the recipients file can be downloaded.
records_uploaded: Option<u32>How many records were uploaded.
parse_error: Option<String>Why parsing failed, when it did.
timestamp: Option<i64>The batch’s timestamp (scheduled run time, or creation time for immediate batches), in epoch seconds.
progress: Option<f64>Completion percentage, from 0 to 100 (list view only).
created_at: Option<String>When the batch was created.
updated_at: Option<String>When the batch was last updated.
extra: Map<String, Value>Any fields the server returned that this SDK does not model yet.