pub struct Recording {
pub id: String,
pub room_id: Option<String>,
pub file: Option<RecordingFile>,
pub webhook: Option<WebhookDeliverySummary>,
pub start: Option<String>,
pub end: Option<String>,
pub links: ResourceLinks,
pub extra: Map<String, Value>,
}Expand description
A composited room recording.
Fields
id: StringThe recording id.
room_id: Option<String>The room that was recorded.
file: Option<RecordingFile>The produced file.
webhook: Option<WebhookDeliverySummary>A summary of the webhook deliveries for this recording.
start: Option<String>When the recording started.
end: Option<String>When the recording ended, or None if it is still running.
links: ResourceLinksHATEOAS-style links to related resources.
extra: Map<String, Value>Any fields the server returned that this SDK does not model yet.