CreateBatchCallParams

Struct CreateBatchCallParams 

pub struct CreateBatchCallParams {
Show 15 fields pub batch_name: String, pub phone_number_id: String, pub routing_rule_id: String, pub description: Option<String>, pub timing: Option<BatchCallTiming>, pub timezone: Option<String>, pub scheduled_time: Option<String>, pub scheduled_date: Option<String>, pub allowed_from: Option<String>, pub allowed_until: Option<String>, pub days_of_week: Vec<u32>, pub retry: Option<BatchCallRetryConfig>, pub webhook: Option<BatchCallWebhookConfig>, pub batch_id: Option<String>, pub save_as_draft: Option<bool>,
}
The parameters for BatchCallsResource::create.

Fields

batch_name: String

The display name. Required.

phone_number_id: String

The outbound phone number id. Required.

routing_rule_id: String

The outbound routing rule id, attached to the number. Required.

description: Option<String>

The batch’s description.

timing: Option<BatchCallTiming>

When the batch runs.

timezone: Option<String>

An IANA timezone. Defaults to Asia/Calcutta.

scheduled_time: Option<String>

The scheduled time, as HH:MM. Required when scheduled.

scheduled_date: Option<String>

The scheduled date, as YYYY-MM-DD. Required when scheduled.

allowed_from: Option<String>

The start of the allowed calling window, as HH:MM. Scheduled batches only.

allowed_until: Option<String>

The end of the allowed calling window, as HH:MM.

days_of_week: Vec<u32>

The days the batch may call: 0 is Sunday through 6, Saturday.

retry: Option<BatchCallRetryConfig>

The retry configuration.

webhook: Option<BatchCallWebhookConfig>

The webhook configuration.

batch_id: Option<String>

Finalizes a previously uploaded and parsed draft.

save_as_draft: Option<bool>

Saves as a draft instead of launching.